# $Id: Err.pm 361 2013-07-01 13:30:52Z phil $
#
# author: Philippe Kueck <projects@unixadm.org>
#

package SyncServer::Err;

use strict;
use warnings;


sub new {
	return bless {
		'code' => $_[1], 'msg' => $_[2], 'parent' => (caller(1))[3]
	}, $_[0]
}

sub err  {return 1}
sub code {return $_[0]->{'code'}}
sub msg  {return $_[0]->{'msg'}}

1;

__END__

=head1 NAME

SyncServer::Err - a simple error object

=head1 SYNOPSIS

 use SyncServer::Err;
 my $error = new SyncServer::Err(503, 'An error ocurred');

=head1 DESCRIPTION

This module provides an error object containing an error code and an error description.

=head1 DEPENDENCIES

none.

=head1 ENVIRONMENT

none.

=head1 METHODS

=over 8

=item B<new>(I<CODE>, I<MSG>)

creates a new object providing the error code I<CODE> and (optionally) the message I<MESSAGE>.

=item B<err>()

a dummy function that is used whether or not the object exists.

=item B<code>()

returns the error code.

=item B<msg>()

returns the error message.

=back

=head1 EXAMPLES

 my $err;
 if (somethingwentwront) { $err = new SyncServer::Error(503, 'ohnoes') }
 if (eval{$err->err}) { printf "error: %s\n", $err->msg; }

=head1 AUTHOR

Philippe Kueck <projects at unixadm dot org>

=cut
